Administration — CubicWeb 3.13.2

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »

# Administration

This part is for installation and administration of the CubicWeb framework and instances based on that framework.

- 1. Installation of a CubicWeb environment
- 2. Installing a development environement on Windows
- 3. Set-up of a CubicWeb environment
- 4. `cubicweb-ctl` tool
- 5. Creation of your first instance
- 6. Configure an instance
- 7. User interface for web site configuration
- 8. Multiple sources of data
- 9. LDAP integration
- 10. Working with a distributed client (using Pyro)
- 11. Migrating cubicweb instances - benefits from a distributed architecture
- 12. Backups (mostly with postgresql)
- 13. RQL logs

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.13.2 »